/***************************************************************************/
/*    This code is part of WWW grabber called pavuk                        */
/*    Copyright (c) 1997 - 2001 Stefan Ondrejicka                          */
/*    Distributed under GPL 2 or later                                     */
/***************************************************************************/

#ifndef _tr_h_
#define _tr_h_

extern char *tr_chr_chr(char *, char *, char *);
extern char *tr_str_str(char *, char *, char *);
extern char *tr_del_chr(char *, char *);
extern char *tr(char *);

#endif
